@@ -5,9 +5,8 @@ from sentry_sdk.integrations.asgi import SentryAsgiMiddleware
 from sentry_sdk.integrations.redis import RedisIntegration
 
 from fief import __version__
-from fief.apps import admin_app, auth_app
+from fief.apps import admin_app, admin_frontend_app, auth_app
 from fief.db import account_engine_manager
-from fief.services.account_creation import create_global_fief_account
 from fief.settings import settings
 
 sentry_sdk.init(
@@ -28,15 +27,11 @@ app.add_middleware(
     allow_headers=["*"],
 )
 
-app.mount("/admin", admin_app)
+app.mount("/admin", admin_frontend_app)
+app.mount("/api", admin_app)
 app.mount("/", auth_app)
 
 
-@app.on_event("startup")
-async def on_startup():
-    await create_global_fief_account()
-
-
 @app.on_event("shutdown")
 async def on_shutdown():
     await account_engine_manager.close_all()
