@@ -1,7 +1,12 @@
 from fastapi import Depends
 
 from fief.db import AsyncSession, get_global_async_session
-from fief.managers import AccountManager, AdminSessionTokenManager, get_manager
+from fief.managers import (
+    AccountManager,
+    AccountUserManager,
+    AdminSessionTokenManager,
+    get_manager,
+)
 
 
 async def get_account_manager(
@@ -14,3 +19,9 @@ async def get_admin_session_token_manager(
     session: AsyncSession = Depends(get_global_async_session),
 ) -> AdminSessionTokenManager:
     return get_manager(AdminSessionTokenManager, session)
+
+
+async def get_account_user_manager(
+    session: AsyncSession = Depends(get_global_async_session),
+) -> AccountUserManager:
+    return get_manager(AccountUserManager, session)
