@@ -1,4 +1,5 @@
 from fief.managers.account import AccountManager
+from fief.managers.account_user import AccountUserManager
 from fief.managers.admin_session_token import AdminSessionTokenManager
 from fief.managers.authorization_code import AuthorizationCodeManager
 from fief.managers.base import get_manager
@@ -8,9 +9,11 @@ from fief.managers.login_session import LoginSessionManager
 from fief.managers.refresh_token import RefreshTokenManager
 from fief.managers.session_token import SessionTokenManager
 from fief.managers.tenant import TenantManager
+from fief.managers.user import UserManager
 
 __all__ = [
     "AccountManager",
+    "AccountUserManager",
     "AdminSessionTokenManager",
     "AuthorizationCodeManager",
     "ClientManager",
@@ -19,5 +22,6 @@ __all__ = [
     "RefreshTokenManager",
     "SessionTokenManager",
     "TenantManager",
+    "UserManager",
     "get_manager",
 ]
