@@ -1,4 +1,5 @@
 from fief.models.account import Account
+from fief.models.account_user import AccountUser
 from fief.models.admin_session_token import AdminSessionToken
 from fief.models.authorization_code import AuthorizationCode
 from fief.models.base import AccountBase, GlobalBase
@@ -14,6 +15,7 @@ from fief.models.user import User
 __all__ = [
     "Account",
     "AccountBase",
+    "AccountUser",
     "AdminSessionToken",
     "AuthorizationCode",
     "Client",
